/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.activities;

import android.os.Bundle;
import android.widget.Button;
import android.widget.TextView;

import butterknife.BindView;
import butterknife.ButterKnife;
import com.luca0n.joguitos.pluck.R;
import com.luca0n.joguitos.pluck.trivia.TriviaGame;
import com.luca0n.joguitos.pluck.util.UiUtil;

public class TriviaGameResultsActivity extends BaseActivity {
	static final String EXTRA_TRIVIA_GAME = "extra_trivia_game";

	@BindView(R.id.text_results_correct)
	TextView textResultsCorrect;
	@BindView(R.id.text_results_wrong)
	TextView textResultsWrong;
	@BindView(R.id.text_results_total)
	TextView textResultsTotal;
	@BindView(R.id.text_results_time_elapsed)
	TextView textResultsTimeElapsed;
	@BindView(R.id.button_return_to_menu)
	Button buttonReturnToMenu;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		UiUtil.setTheme(this);
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_trivia_game_results);
		ButterKnife.bind(this);

		Bundle bundle = getIntent().getExtras();
		TriviaGame game = (TriviaGame) bundle.get(EXTRA_TRIVIA_GAME);

		int correctTotal = 0;

		for (boolean result : game.getResults()) {
			if (result) {
				correctTotal++;
			}
		}

		// Calculate the difference between startEpoch and endEpoch
		float timeDifference = (game.getEndEpoch() - game.getStartEpoch())/1000F;

		textResultsCorrect.setText(String.valueOf(correctTotal));
		textResultsWrong.setText(String.valueOf(game.getQuestionsCount() - correctTotal));
		textResultsTotal.setText(String.valueOf(game.getQuestionsCount()));
		if (timeDifference < 60000L)
			// Use the "n seconds" string since the time difference was less than 60 seconds.
			textResultsTimeElapsed.setText(
					String.format(getString(R.string.ui_results_time_elapsed_format_seconds), timeDifference)
					);
		else
			// Use the "n minutes" string since the time difference was equal to or more than 60 seconds.
			textResultsTimeElapsed.setText(
					String.format(getString(R.string.ui_results_time_elapsed_format_minutes), timeDifference / 60F)
					);

		buttonReturnToMenu.setOnClickListener(v -> finish());
	}
}
